=encoding utf8

=head1

Locale::CLDR::Locales::Kde::Any::Tz - Package for language Makonde

=cut

package Locale::CLDR::Locales::Kde::Any::Tz;
# This file auto generated from Data/common/main/kde_TZ.xml
#	on Mon 11 Apr  5:31:30 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.34.1');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

extends('Locale::CLDR::Locales::Kde::Any');
no Moo;

1;

# vim: tabstop=4
